==========
click_demo
==========


.. image:: https://img.shields.io/pypi/v/click_demo.svg
        :target: https://pypi.python.org/pypi/click_demo

.. image:: https://img.shields.io/travis/parashuram-patil/click_demo.svg
        :target: https://travis-ci.org/parashuram-patil/click_demo

.. image:: https://readthedocs.org/projects/click-demo/badge/?version=latest
        :target: https://click-demo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Simple click greeting commands, Hi and Bye only :)


* Free software: MIT license
* Documentation: https://click-demo.readthedocs.io.


Features
--------

* Simple click greeting commands that takes name and greets
    - Commands Available
        - Hi
        - Bye

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
